#
# Copyright (c) 2020 Kian Cross
#

BLACK = 0
RED = 1
GREEN = 2
YELLOW = 3
BLUE = 4
MAGENTA = 5
CYAN = 6
WHITE = 7

FOREGROUND_START_CODE = 30
BACKGROUND_START_CODE = 40

FOREGROUND_CODE = 38
BACKGROUND_CODE = 48
